@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.exceptions.LocalizableStrings;
 
 /**
  * Exception messages for {@link DataException} that must be translated.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class DataExceptionMessages implements LocalizableStrings {
@@ -73,9 +73,12 @@ public final class DataExceptionMessages implements LocalizableStrings {
     public static final String ERROR_MSG = "An error occurred: %1$s";
 
     public static final String TRUNCATED_MSG = "The following field(s) are too long: %1$s";
-    
+
     public static final String UNABLE_TO_CHANGE_DATA_MSG = "Unable to change data. (%1$s)";
 
+    // An I/O error occurred: %1$s
+    public static final String IO_ERROR_MSG = "An I/O error occurred: %1$s";
+
     /**
      * Prevent instantiation.
      */
