@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import java.util.Map;
 
 /**
  * {@link DataProperties} - Container for data properties like content type, version, character set, name , size, etc.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DataProperties implements Cloneable {
@@ -85,6 +85,16 @@ public final class DataProperties implements Cloneable {
      */
     public static final String PROPERTY_SIZE = "com.openexchange.conversion.size";
 
+    /**
+     * Property for disposition
+     */
+    public static final String PROPERTY_DISPOSITION = "com.openexchange.conversion.disposition";
+    
+    /**
+     * 
+     */
+    public static final String PROPERTY_EMAIL_HEADER_PREFIX= "com.openexchange.conversion.email.header";
+
     /**
      * Constant for empty data arguments
      */
@@ -101,7 +111,7 @@ public final class DataProperties implements Cloneable {
 
     /**
      * Initializes a new {@link DataProperties}
-     * 
+     *
      * @param initialCapacity The initial capacity
      */
     public DataProperties(final int initialCapacity) {
@@ -119,7 +129,7 @@ public final class DataProperties implements Cloneable {
 
     /**
      * Returns <code>true</code> if these data properties contain a mapping for the specified key.
-     * 
+     *
      * @param key The key whose presence in these data properties is to be tested.
      * @return <code>true</code> if this data properties contain a mapping for the specified key; otherwise <code>false</code>
      */
@@ -132,7 +142,7 @@ public final class DataProperties implements Cloneable {
      * value of <code>null</code> does not necessarily indicate that the data properties contain no mapping for the key; it's also possible
      * that the data properties explicitly map the key to <code>null</code>. The {@link #containsKey(String)} operation may be used to
      * distinguish these two cases.
-     * 
+     *
      * @param key The key whose associated value is to be returned.
      * @return The value to for the specified key, or <code>null</code> if the data properties contain no mapping for this key.
      */
@@ -143,19 +153,25 @@ public final class DataProperties implements Cloneable {
     /**
      * Associates the specified value with the specified key. If the data properties previously contained a mapping for this key, the old
      * value is replaced by the specified value.
-     * 
+     *
      * @param key The key with which the specified value is to be associated.
      * @param value The value to be associated with the specified key.
      * @return The previous value associated with specified key, or <code>null</code> if there was no mapping for key. A <code>null</code>
      *         return can also indicate that the data properties previously associated <code>null</code> with the specified key.
      */
     public String put(final String key, final String value) {
+        if (null == value) {
+            /*
+             * Consider as a remove
+             */
+            return map.remove(key);
+        }
         return map.put(key, value);
     }
 
     /**
      * Removes the mapping for this key from these data properties if it is present.
-     * 
+     *
      * @param key The key whose mapping is to be removed from the data properties.
      * @return The previous value associated with specified key, or <code>null</code> if there was no mapping for key.
      */
@@ -165,7 +181,7 @@ public final class DataProperties implements Cloneable {
 
     /**
      * Gets this data properties as a {@link Map java.util.Map}
-     * 
+     *
      * @return This data properties as a {@link Map java.util.Map}
      */
     public Map<String, String> toMap() {
